@@ -9,7 +9,7 @@ use 5.006;
 
 use vars (qw($VERSION $Tolerance $Min_samples_number));
 
-$VERSION = '3.0608';
+$VERSION = '3.0610';
 
 $Tolerance = 0.0;
 $Min_samples_number = 4;
@@ -18,7 +18,7 @@ package Statistics::Descriptive::Sparse;
 
 use vars qw($VERSION);
 
-$VERSION = '3.0608';
+$VERSION = '3.0610';
 
 use vars qw(%fields);
 use Carp;
@@ -76,15 +76,15 @@ sub _make_private_accessors
 
 ##Define the fields to be used as methods
 %fields = (
-  count			=> 0,
-  mean			=> undef,
-  sum			=> undef,
-  sumsq			=> undef,
-  min			=> undef,
-  max			=> undef,
-  mindex		=> undef,
-  maxdex		=> undef,
-  sample_range		=> undef,
+  count                 => 0,
+  mean                  => undef,
+  sum                   => undef,
+  sumsq                 => undef,
+  min                   => undef,
+  max                   => undef,
+  mindex                => undef,
+  maxdex                => undef,
+  sample_range          => undef,
   variance              => undef,
   );
 
@@ -118,10 +118,10 @@ sub add_data {
     my $aref;
 
     if (ref $_[0] eq 'ARRAY') {
-	$aref = $_[0];
+        $aref = $_[0];
     }
     else {
-	$aref = \@_;
+        $aref = \@_;
     }
 
     ##If we were given no data, we do nothing.
@@ -131,20 +131,20 @@ sub add_data {
 
     if (!defined($min = $self->min()))
     {
-	$min = $aref->[$mindex = 0];
+        $min = $aref->[$mindex = 0];
     }
     else
     {
-	$mindex = $self->mindex();
+        $mindex = $self->mindex();
     }
 
     if (!defined($max = $self->max()))
     {
-	$max = $aref->[$maxdex = 0];
+        $max = $aref->[$maxdex = 0];
     }
     else
     {
-	$maxdex = $self->maxdex();
+        $maxdex = $self->maxdex();
     }
 
     $sum   = $self->sum();
@@ -153,17 +153,17 @@ sub add_data {
 
     ##Calculate new mean, sumsq, min and max;
     foreach ( @{ $aref } ) {
-	$sum += $_;
-	$sumsq += $_**2;
-	$count++;
-	if ($_ >= $max) {
-	    $max = $_;
-	    $maxdex = $count-1;
-	}
-	if ($_ <= $min) {
-	    $min = $_;
-	    $mindex = $count-1;
-	}
+        $sum += $_;
+        $sumsq += $_**2;
+        $count++;
+        if ($_ >= $max) {
+            $max = $_;
+            $maxdex = $count-1;
+        }
+        if ($_ <= $min) {
+            $min = $_;
+            $mindex = $count-1;
+        }
     }
 
     $self->min($min);
@@ -213,7 +213,7 @@ sub variance {
         $self->_variance($variance);
 
         #  Return now to avoid re-entering this sub
-	#  (and therefore save time when many objects are used).
+        #  (and therefore save time when many objects are used).
         return $variance;
     }
 
@@ -238,7 +238,7 @@ package Statistics::Descriptive::Full;
 
 use vars qw($VERSION);
 
-$VERSION = '3.0608';
+$VERSION = '3.0610';
 
 use Carp;
 use POSIX ();
@@ -1162,9 +1162,20 @@ not changed>
 
 =item $stat->add_data_with_samples([{1 => 10}, {2 => 20}, {3 => 30},]);
 
-Add data to the statistics variable and set the number of samples each value has been
-built with. The data is the key of each element of the input array ref, while
-the value is the number of samples: [{data1 => smaples1}, {data2 => samples2}, ...]
+Add data to the statistics variable and set the number of samples each value
+has been built with. The data is the key of each element of the input array
+ref, while the value is the number of samples: [{data1 => smaples1}, {data2 =>
+samples2}, ...].
+
+B<NOTE:> The number of samples is only used by the smoothing function and is
+ignored otherwise. It is not equivalent to repeat count. In order to repeat
+a certain datum more than one time call add_data() like this:
+
+    my $value = 5;
+    my $repeat_count = 10;
+    $stat->add_data(
+        [ ($value) x $repeat_count ]
+    );
 
 =item $stat->get_data();
 
@@ -1517,7 +1528,7 @@ Previously:
 Colin Kuskie
 
 My email address can be found at http://www.perl.com under Who's Who
-or at: http://search.cpan.org/author/COLINK/.
+or at: https://metacpan.org/author/COLINK .
 
 =head1 CONTRIBUTORS
 
